==> apache-cxf-3.5.2-src.tar.gz: apache-cxf-3.5.2-src/rt/databinding/aegis/src/test/java/org/apache/cxf/aegis/type/java5/CollectionServiceInterface.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.aegis.type.java5;


import java.util.ArrayList;
import java.util.Collection;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.SortedSet;
import java.util.Stack;

import org.w3c.dom.Document;

public interface CollectionServiceInterface {

    Collection<String> getStrings();

    void setLongs(Collection<Long> longs);

    Collection<?> getUnannotatedStrings();

    Collection<Collection<String>> getStringCollections();

    void takeDoubleList(List<Double> doublesList);

    String takeSortedStrings(SortedSet<String> strings);

    //CHECKSTYLE:OFF
    String takeUnsortedSet(HashSet<String> strings); //NOPMD
    String takeStack(Stack<String> strings);
    String takeArrayList(ArrayList<String> strings); //NOPMD
    //CHECKSTYLE:ON

    void method1(List<String> headers1);

    void mapOfMapWithStringAndPojo(Map<String, Map<String, BeanWithGregorianDate>> bigParam);

    Collection<double[]> returnCollectionOfPrimitiveArrays();

    Collection<Document[]> returnCollectionOfDOMFragments();
}

==> apache-cxf-3.6.9-src.tar.gz: apache-cxf-3.6.9-src/rt/databinding/aegis/src/test/java/org/apache/cxf/aegis/type/java5/CollectionServiceInterface.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.aegis.type.java5;


import java.util.ArrayList;
import java.util.Collection;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.SortedSet;
import java.util.Stack;

import org.w3c.dom.Document;

public interface CollectionServiceInterface {

    Collection<String> getStrings();

    void setLongs(Collection<Long> longs);

    Collection<?> getUnannotatedStrings();

    Collection<Collection<String>> getStringCollections();

    void takeDoubleList(List<Double> doublesList);

    String takeSortedStrings(SortedSet<String> strings);

    //CHECKSTYLE:OFF
    String takeUnsortedSet(HashSet<String> strings);
    String takeStack(Stack<String> strings);
    String takeArrayList(ArrayList<String> strings);
    //CHECKSTYLE:ON

    void method1(List<String> headers1);

    void mapOfMapWithStringAndPojo(Map<String, Map<String, BeanWithGregorianDate>> bigParam);

    Collection<double[]> returnCollectionOfPrimitiveArrays();

    Collection<Document[]> returnCollectionOfDOMFragments();
}
